aboutsummaryrefslogtreecommitdiffstats
path: root/drv_LCD2USB.c
diff options
context:
space:
mode:
Diffstat (limited to 'drv_LCD2USB.c')
-rw-r--r--drv_LCD2USB.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/drv_LCD2USB.c b/drv_LCD2USB.c
index 493fbac..b14489f 100644
--- a/drv_LCD2USB.c
+++ b/drv_LCD2USB.c
@@ -1,7 +1,7 @@
/* $Id$
* $URL$
*
* driver for USB2LCD display interface
* see http://www.harbaum.org/till/lcd2usb for schematics
*
* Copyright 2005 Till Harbaum <till@harbaum.org>
@@ -569,7 +569,7 @@ static void plugin_brightness(RESULT * result, RESULT * arg1)
/* list models */
int drv_L2U_list(void)
{
- printf("USB2LCD display interface");
+ printf("LCD2USB homebrew USB interface for HD44780 text displays");
return 0;
}
@@ -1,7 +1,7 @@
* $URL$
*
- * driver for USB2LCD display interface
+ * driver for LCD2USB display interface
* see http://www.harbaum.org/till/lcd2usb for schematics
*